@@ -1,7 +1,8 @@
-# Re-built by Itz-fork
 # Original Author: Codec04
-# Project: Py-Gofile
+# Re-built by Itz-fork
+# Project: Gofile2
 
 from .gofile2 import Gofile
+from .async_gofile2 import Async_Gofile
 
-__version__ = "v1.0"
\ No newline at end of file
+__version__ = "v1.2"
\ No newline at end of file
